@@ -6,6 +6,7 @@
 #' for which datasets shall be listed.
 #' @param dataset a character string specifying the dataset for which 
 #' attributes shall be listed.
+#' @param mute_citation logical value indicating whether citation message should be muted.
 #' @author Hajk-Georg Drost
 #' @examples
 #' \dontrun{
@@ -25,7 +26,7 @@
 #' \code{\link{organismFilters}}, \code{\link{organismAttributes}}
 #' @export
 
-getAttributes <- function(mart, dataset){
+getAttributes <- function(mart, dataset, mute_citation = FALSE){
     
     if ((!is.character(mart)) || (!is.character(dataset)))
         stop("Please use a character string as mart or dataset.",
@@ -120,6 +121,8 @@ getAttributes <- function(mart, dataset){
                       colClasses = rep("character", 2))
     colnames(attrBioMart) <- c("name", "description")
     
+    please_cite_biomartr(mute_citation = mute_citation)
+    
     return(attrBioMart)
 }
 
