@@ -20,7 +20,7 @@ read_rm <- function(file) {
     })
     
     
-    rm_file <- tibble::as_tibble(do.call(rbind, rm_file))
+    rm_file <- as.data.frame(do.call(rbind, rm_file))
     colnames(rm_file) <- c(
         "sw_score",
         "perc_div",
@@ -39,6 +39,8 @@ read_rm <- function(file) {
     )
     qry_end <- qry_start <- NULL
     
+    rm_file <- tibble::as_tibble(rm_file)
+    
     nrow_before_filtering <- nrow(rm_file)
         
     suppressWarnings(rm_file <- dplyr::mutate(rm_file,
